aboutsummaryrefslogtreecommitdiff
path: root/sys/arm/arm/pmap-v6.c
diff options
context:
space:
mode:
authorKonstantin Belousov <kib@FreeBSD.org>2018-08-29 12:24:19 +0000
committerKonstantin Belousov <kib@FreeBSD.org>2018-08-29 12:24:19 +0000
commitf0165b1ca68bff74bd6196d796b3fa5b7a732ca2 (patch)
tree2b101ac80392495151eda4453830b7211a245c55 /sys/arm/arm/pmap-v6.c
parent76f6651cf08f1907a7cdb2501d1c891fbdc4f4d0 (diff)
downloadsrc-f0165b1ca68bff74bd6196d796b3fa5b7a732ca2.tar.gz
src-f0165b1ca68bff74bd6196d796b3fa5b7a732ca2.zip
Remove {max/min}_offset() macros, use vm_map_{max/min}() inlines.
Exposing max_offset and min_offset defines in public headers is causing clashes with variable names, for example when building QEMU. Based on the submission by: royger Reviewed by: alc, markj (previous version) Sponsored by: The FreeBSD Foundation (kib) MFC after: 1 week Approved by: re (marius) Differential revision: https://reviews.freebsd.org/D16881
Notes
Notes: svn path=/head/; revision=338370
Diffstat (limited to 'sys/arm/arm/pmap-v6.c')
-rw-r--r--sys/arm/arm/pmap-v6.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/sys/arm/arm/pmap-v6.c b/sys/arm/arm/pmap-v6.c
index 8dd74f15d925..ceedc75cb941 100644
--- a/sys/arm/arm/pmap-v6.c
+++ b/sys/arm/arm/pmap-v6.c
@@ -2043,21 +2043,21 @@ pmap_growkernel(vm_offset_t addr)
* not called, it could be first unused KVA (which is not
* rounded up to PTE1_SIZE),
*
* (2) when all KVA space is mapped and kernel_map->max_offset
* address is not rounded up to PTE1_SIZE. (For example,
* it could be 0xFFFFFFFF.)
*/
kernel_vm_end = pte1_roundup(kernel_vm_end);
mtx_assert(&kernel_map->system_mtx, MA_OWNED);
addr = roundup2(addr, PTE1_SIZE);
- if (addr - 1 >= kernel_map->max_offset)
- addr = kernel_map->max_offset;
+ if (addr - 1 >= vm_map_max(kernel_map))
+ addr = vm_map_max(kernel_map);
while (kernel_vm_end < addr) {
pte1 = pte1_load(kern_pte1(kernel_vm_end));
if (pte1_is_valid(pte1)) {
kernel_vm_end += PTE1_SIZE;
- if (kernel_vm_end - 1 >= kernel_map->max_offset) {
- kernel_vm_end = kernel_map->max_offset;
+ if (kernel_vm_end - 1 >= vm_map_max(kernel_map)) {
+ kernel_vm_end = vm_map_max(kernel_map);
break;
}
continue;
@@ -2099,8 +2099,8 @@ pmap_growkernel(vm_offset_t addr)
pmap_kenter_pte1(kernel_vm_end, PTE1_LINK(pt2_pa));
kernel_vm_end = kernel_vm_end_new;
- if (kernel_vm_end - 1 >= kernel_map->max_offset) {
- kernel_vm_end = kernel_map->max_offset;
+ if (kernel_vm_end - 1 >= vm_map_max(kernel_map)) {
+ kernel_vm_end = vm_map_max(kernel_map);
break;
}
}
@@ -2043,21 +2043,21 @@ pmap_growkernel(vm_offset_t addr)
* rounded up to PTE1_SIZE),
*
- * (2) when all KVA space is mapped and kernel_map->max_offset
+ * (2) when all KVA space is mapped and vm_map_max(kernel_map)
* address is not rounded up to PTE1_SIZE. (For example,
* it could be 0xFFFFFFFF.)